@@ -3,7 +3,7 @@ This module contains `jsondict`, the decorator for typed dicts used with
 jsonclasses.
 """
 from typing import Optional, Union, Callable, overload
-from .jsonclass_graph import JSONClassGraph
+from .cgraph import CGraph
 
 
 @overload
@@ -39,8 +39,8 @@ def jsondict(
     if cls is not None:
         if not isinstance(cls, type):
             raise ValueError('@jsondict should be used to decorate a class.')
-        class_graph = JSONClassGraph(class_graph)
-        class_graph.put_dict(cls)
+        cgraph = CGraph(class_graph)
+        cgraph.put_dict(cls)
         return cls
     else:
         def parametered_jsondict(cls):
