@@ -1,6 +1,6 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING
-from jsonclasses import jsonclass, Link, linkto
+from typing import Annotated, TYPE_CHECKING
+from jsonclasses import jsonclass, linkto
 if TYPE_CHECKING:
     from tests.classes.linked_user import LinkedUser
 
@@ -8,4 +8,4 @@ if TYPE_CHECKING:
 @jsonclass
 class LinkedProfile:
     name: str
-    user: Link[LinkedUser, linkto]
+    user: Annotated[LinkedUser, linkto]
