@@ -1,6 +1,6 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING
-from jsonclasses import jsonclass, Link, linkedby
+from typing import Annotated, TYPE_CHECKING
+from jsonclasses import jsonclass, linkedby
 if TYPE_CHECKING:
     from tests.classes.linked_profile import LinkedProfile
 
@@ -8,4 +8,4 @@ if TYPE_CHECKING:
 @jsonclass
 class LinkedUser:
     name: str
-    profile: Link[LinkedProfile, linkedby('user')]
+    profile: Annotated[LinkedProfile, linkedby('user')]
