@@ -1,6 +1,6 @@
 from __future__ import annotations
 from unittest import TestCase
-from jsonclasses.exceptions import AbstractJSONClassException
+from jsonclasses.excs import AbstractJSONClassException
 from tests.classes.abstract_object import (AbstractObject, MyObject,
                                            NonAbstractObject,
                                            DefaultNonAbstractObject)
