@@ -2,8 +2,8 @@ from typing import Optional, Union
 from unittest import TestCase
 from datetime import datetime, date
 from jsonclasses import jsonclass
-from jsonclasses.field_definition import FieldType, FieldStorage
-from jsonclasses.exceptions import ValidationException
+from jsonclasses.fdef import FType, FStore
+from jsonclasses.excs import ValidationException
 from tests.classes.linked_author import LinkedAuthor
 from tests.classes.linked_article import LinkedArticle
 from tests.classes.linked_user import LinkedUser
@@ -372,10 +372,10 @@ class TestAutoTypes(TestCase):
         @jsonclass(class_graph='test_marker_auto_gen')
         class TestUnionDictType:
             val: 'Union[dict[str, int], int]'
-        cfield = TestUnionDictType.definition.field_named('val')
-        utypes = cfield.definition.union_types
-        self.assertEqual(utypes[0].definition.field_type, FieldType.DICT)
-        self.assertEqual(utypes[1].definition.field_type, FieldType.INT)
+        cfield = TestUnionDictType.cdef.field_named('val')
+        utypes = cfield.fdef.raw_union_types
+        self.assertEqual(utypes[0].fdef.field_type, FType.DICT)
+        self.assertEqual(utypes[1].fdef.field_type, FType.INT)
 
     def test_auto_generates_optional_union_with_dict_with_str_type(self):
         @jsonclass(class_graph='test_marker_auto_gen')
@@ -388,49 +388,49 @@ class TestAutoTypes(TestCase):
         setting = AutoSetting()
         self.assertRaisesRegex(
             ValidationException,
-            "Value at 'preference.ios' should not be None.",
+            "'preference\\.ios': value required",
             setting.validate)
 
     def test_auto_generates_nonnull_shape_with_typed_dict_str_form(self):
         setting = AutoStrSetting()
         self.assertRaisesRegex(
             ValidationException,
-            "Value at 'preference.ios' should not be None.",
+            "'preference\\.ios': value required",
             setting.validate)
 
     def test_auto_generates_1_to_1_links(self):
-        profile_field = LinkedUser.definition.field_named('profile')
-        self.assertEqual(profile_field.definition.field_type,
-                         FieldType.INSTANCE)
-        self.assertEqual(profile_field.definition.field_storage,
-                         FieldStorage.FOREIGN_KEY)
-        self.assertEqual(profile_field.definition.foreign_key, 'user')
-        self.assertEqual(profile_field.definition.use_join_table, False)
+        profile_field = LinkedUser.cdef.field_named('profile')
+        self.assertEqual(profile_field.fdef.field_type,
+                         FType.INSTANCE)
+        self.assertEqual(profile_field.fdef.field_storage,
+                         FStore.FOREIGN_KEY)
+        self.assertEqual(profile_field.fdef.foreign_key, 'user')
+        self.assertEqual(profile_field.fdef.use_join_table, False)
 
-        user_field = LinkedProfile.definition.field_named('user')
-        self.assertEqual(user_field.definition.field_type,
-                         FieldType.INSTANCE)
-        self.assertEqual(user_field.definition.field_storage,
-                         FieldStorage.LOCAL_KEY)
-        self.assertEqual(user_field.definition.foreign_key, None)
-        self.assertEqual(user_field.definition.use_join_table, None)
+        user_field = LinkedProfile.cdef.field_named('user')
+        self.assertEqual(user_field.fdef.field_type,
+                         FType.INSTANCE)
+        self.assertEqual(user_field.fdef.field_storage,
+                         FStore.LOCAL_KEY)
+        self.assertEqual(user_field.fdef.foreign_key, None)
+        self.assertEqual(user_field.fdef.use_join_table, None)
 
     def test_auto_generates_1_to_many_links(self):
-        articles_field = LinkedAuthor.definition.field_named('articles')
-        self.assertEqual(articles_field.definition.field_type,
-                         FieldType.LIST)
-        self.assertEqual(articles_field.definition.field_storage,
-                         FieldStorage.FOREIGN_KEY)
-        self.assertEqual(articles_field.definition.foreign_key, 'author')
-        self.assertEqual(articles_field.definition.use_join_table, False)
+        articles_field = LinkedAuthor.cdef.field_named('articles')
+        self.assertEqual(articles_field.fdef.field_type,
+                         FType.LIST)
+        self.assertEqual(articles_field.fdef.field_storage,
+                         FStore.FOREIGN_KEY)
+        self.assertEqual(articles_field.fdef.foreign_key, 'author')
+        self.assertEqual(articles_field.fdef.use_join_table, False)
 
-        author_field = LinkedArticle.definition.field_named('author')
-        self.assertEqual(author_field.definition.field_type,
-                         FieldType.INSTANCE)
-        self.assertEqual(author_field.definition.field_storage,
-                         FieldStorage.LOCAL_KEY)
-        self.assertEqual(author_field.definition.foreign_key, None)
-        self.assertEqual(author_field.definition.use_join_table, None)
+        author_field = LinkedArticle.cdef.field_named('author')
+        self.assertEqual(author_field.fdef.field_type,
+                         FType.INSTANCE)
+        self.assertEqual(author_field.fdef.field_storage,
+                         FStore.LOCAL_KEY)
+        self.assertEqual(author_field.fdef.foreign_key, None)
+        self.assertEqual(author_field.fdef.use_join_table, None)
 
     def test_auto_generates_many_to_many_links(self):
         customer1 = LinkedCustomer(name='C1')
