@@ -1,6 +1,6 @@
 from __future__ import annotations
 from unittest import TestCase
-from jsonclasses.exceptions import ValidationException
+from jsonclasses.excs import ValidationException
 from tests.classes.simple_book import SimpleBook
 
 
@@ -16,7 +16,7 @@ class TestBool(TestCase):
             book.validate()
         self.assertEqual(len(context.exception.keypath_messages), 1)
         self.assertEqual(context.exception.keypath_messages['published'],
-                         "Value '1' at 'published' should be bool.")
+                         "value is not bool")
 
     def test_bool_is_bool_when_tojson(self):
         book = SimpleBook(published=False)
