@@ -1,6 +1,6 @@
 from __future__ import annotations
 from unittest import TestCase
-from jsonclasses.exceptions import ValidationException
+from jsonclasses.excs import ValidationException
 from tests.classes.simple_balance import SimpleBalance
 
 
@@ -21,7 +21,7 @@ class TestFloat(TestCase):
             balance.validate()
         self.assertEqual(len(context.exception.keypath_messages), 1)
         self.assertEqual(context.exception.keypath_messages['balance'],
-                         "Value '20' at 'balance' should be float.")
+                         "value is not float")
 
     def test_float_is_float_when_tojson(self):
         balance = SimpleBalance(balance=5.0)
