@@ -2,7 +2,7 @@ from __future__ import annotations
 from unittest import TestCase
 from typing import List, Dict, Optional
 from jsonclasses import jsonclass, types
-from jsonclasses.exceptions import ValidationException
+from jsonclasses.excs import ValidationException
 
 
 @jsonclass(class_graph='test_instanceof_22')
@@ -95,9 +95,9 @@ input = {
 }
 
 
-class TestInstanceOfValidator(TestCase):
+class TestInstanceOfModifier(TestCase):
 
-    def test_instanceof_validator_creates_instanceof_designated_class_on_transforming(self):
+    def test_instanceof_modifier_creates_instanceof_designated_class_on_transforming(self):
         @jsonclass(class_graph='test_instanceof_1')
         class Address:
             line1: str = types.str
@@ -110,7 +110,7 @@ class TestInstanceOfValidator(TestCase):
         user = User(**{'name': 'John', 'address': {'line1': 'London', 'line2': 'Road'}})
         self.assertIsInstance(user.address, Address)
 
-    def test_instanceof_validator_fill_children_defaults(self):
+    def test_instanceof_modifier_fill_children_defaults(self):
         @jsonclass(class_graph='test_instanceof_1_0')
         class Address:
             line1: str = types.str.default('Line1').required
@@ -124,7 +124,7 @@ class TestInstanceOfValidator(TestCase):
         self.assertEqual(user.address.line1, 'Line1')
         self.assertEqual(user.address.line2, 'Line2')
 
-    def test_instanceof_validator_raises_if_type_doesnt_match(self):
+    def test_instanceof_modifier_raises_if_type_doesnt_match(self):
         @jsonclass(class_graph='test_instanceof_1_2')
         class Address:
             line1: str = types.str.required
@@ -143,10 +143,10 @@ class TestInstanceOfValidator(TestCase):
         user.address = NewAddress(line3='1', line4='2')
         self.assertRaisesRegex(
             ValidationException,
-            "Value at 'address' should be instance of 'Address'\\.",
+            "value is not instance of Address",
             user.validate)
 
-    def test_instanceof_validator_validates_using_validator_inside(self):
+    def test_instanceof_modifier_validates_using_modifier_inside(self):
         @jsonclass(class_graph='test_instanceof_2')
         class Address:
             line1: str = types.str.required
@@ -157,9 +157,11 @@ class TestInstanceOfValidator(TestCase):
             name: str = types.str
             address: Address = types.instanceof(Address)
         user = User(**{'name': 'John', 'address': {'line2': 'Road'}})
-        self.assertRaisesRegex(ValidationException, 'Value at \'address\\.line1\' should not be None.', user.validate)
+        self.assertRaisesRegex(ValidationException,
+            "'address\\.line1': value required",
+            user.validate)
 
-    def test_instanceof_validator_convert_subfields_to_json(self):
+    def test_instanceof_modifier_convert_subfields_to_json(self):
         @jsonclass(class_graph='test_instanceof_3')
         class Address:
             line1: str = types.str.required
@@ -173,7 +175,7 @@ class TestInstanceOfValidator(TestCase):
         result = user.tojson()
         self.assertEqual(result, {'name': 'John', 'address': {'line1': 'OK', 'line2': 'Road'}})
 
-    def test_instanceof_validator_creates_instances_inside_list(self):
+    def test_instanceof_modifier_creates_instances_inside_list(self):
         @jsonclass(class_graph='test_instanceof_4')
         class Address:
             line1: str = types.str
@@ -193,7 +195,7 @@ class TestInstanceOfValidator(TestCase):
         self.assertEqual(user.addresses[0]._data_dict, {'line1': 'London', 'line2': 'Road'})
         self.assertEqual(user.addresses[1]._data_dict, {'line1': 'Paris', 'line2': 'Road'})
 
-    def test_instanceof_validator_validates_instances_inside_list(self):
+    def test_instanceof_modifier_validates_instances_inside_list(self):
         @jsonclass(class_graph='test_instanceof_5')
         class Address:
             line1: str = types.str.required
@@ -209,7 +211,7 @@ class TestInstanceOfValidator(TestCase):
         ]})
         self.assertRaises(ValidationException, user.validate)
 
-    def test_instanceof_validator_converts_to_json_inside_list(self):
+    def test_instanceof_modifier_converts_to_json_inside_list(self):
         @jsonclass(class_graph='test_instanceof_6')
         class Address:
             line1: str = types.str
@@ -227,7 +229,7 @@ class TestInstanceOfValidator(TestCase):
         desired = {'name': 'John', 'addresses': [{'line1': 'London', 'line2': 'Road'}, {'line1': 'Paris', 'line2': 'Road'}]}
         self.assertEqual(result, desired)
 
-    def test_instanceof_validator_allow_argument_to_be_string(self):
+    def test_instanceof_modifier_allow_argument_to_be_string(self):
         @jsonclass(class_graph='test_instanceof_7')
         class Post:
             title: str = types.str
@@ -331,7 +333,7 @@ class TestInstanceOfValidator(TestCase):
         class User:
             name: str
             staff: Staff = types.instanceof('Staff').strict.required
-        with self.assertRaisesRegex(ValidationException, "Key 'boom' at 'staff' is not allowed\\."):
+        with self.assertRaisesRegex(ValidationException, "key is not allowed"):
             User(**{'name': 'John', 'staff': {'position': 'CEO', 'boom': True}})
 
     def test_instanceof_raises_if_strict_instance(self):
@@ -344,7 +346,7 @@ class TestInstanceOfValidator(TestCase):
         class User:
             name: str
             staff: Staff = types.instanceof('Staff').required
-        with self.assertRaisesRegex(ValidationException, "Key 'boom' at 'staff' is not allowed\\."):
+        with self.assertRaisesRegex(ValidationException, "'staff\\.boom': key is not allowed"):
             User(**{'name': 'John', 'staff': {'position': 'CEO', 'boom': True}})
 
     def test_instanceof_create_circular_ref_for_local_and_foreign_binding(self):
