@@ -1,6 +1,6 @@
 from __future__ import annotations
 from unittest import TestCase
-from jsonclasses.exceptions import ValidationException
+from jsonclasses.excs import ValidationException
 from tests.classes.group_template import Group, Template
 
 
@@ -9,7 +9,7 @@ class TestPresent(TestCase):
     def test_present_raises_on_blank_foreign_keys(self):
         group = Group(name='group')
         self.assertRaisesRegex(ValidationException,
-                               "Value at 'template' should be present\\.",
+                               "value is not present",
                                group.validate)
 
     def test_present_doesnt_raise_on_present_foreign_field(self):
