@@ -1,6 +1,6 @@
 from __future__ import annotations
 from unittest import TestCase
-from jsonclasses.exceptions import ValidationException
+from jsonclasses.excs import ValidationException
 from tests.classes.simple_article import SimpleArticle
 from tests.classes.linked_profile import LinkedProfile
 from tests.classes.linked_user import LinkedUser
@@ -12,14 +12,14 @@ class TestRequired(TestCase):
         article = SimpleArticle()
         self.assertRaisesRegex(
             ValidationException,
-            "Value at 'title' should not be None\\.",
+            "'title': value required",
             article.validate)
 
     def test_required_raises_when_local_key_is_none(self):
         profile = LinkedProfile(name='profile')
         self.assertRaisesRegex(
             ValidationException,
-            "Value at 'user' should not be None\\.",
+            "'user': value required",
             profile.validate)
 
     def test_required_does_not_raise_when_local_key_is_present(self):
